==> huaweicloudsdkmrs-3.1.112-py2.py3-none-any.whl: huaweicloudsdkmrs/v1/model/component_external_datasource.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ComponentExternalDatasource:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'types': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'types': 'types'
    }

    def __init__(self, name=None, types=None):
        """ComponentExternalDatasource

        The model defined in huaweicloud sdk

        :param name: 外部数据源名称
        :type name: str
        :param types: 外部数据源类型
        :type types: list[str]
        """
        
        

        self._name = None
        self._types = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if types is not None:
            self.types = types

    @property
    def name(self):
        """Gets the name of this ComponentExternalDatasource.

        外部数据源名称

        :return: The name of this ComponentExternalDatasource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ComponentExternalDatasource.

        外部数据源名称

        :param name: The name of this ComponentExternalDatasource.
        :type name: str
        """
        self._name = name

    @property
    def types(self):
        """Gets the types of this ComponentExternalDatasource.

        外部数据源类型

        :return: The types of this ComponentExternalDatasource.
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """Sets the types of this ComponentExternalDatasource.

        外部数据源类型

        :param types: The types of this ComponentExternalDatasource.
        :type types: list[str]
        """
        self._types = types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComponentExternalDatasource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.1.155-py2.py3-none-any.whl: huaweicloudsdkmrs/v1/model/component_external_datasource.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ComponentExternalDatasource:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'types': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'types': 'types'
    }

    def __init__(self, name=None, types=None):
        r"""ComponentExternalDatasource

        The model defined in huaweicloud sdk

        :param name: 外部数据源名称
        :type name: str
        :param types: 外部数据源类型
        :type types: list[str]
        """
        
        

        self._name = None
        self._types = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if types is not None:
            self.types = types

    @property
    def name(self):
        r"""Gets the name of this ComponentExternalDatasource.

        外部数据源名称

        :return: The name of this ComponentExternalDatasource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this ComponentExternalDatasource.

        外部数据源名称

        :param name: The name of this ComponentExternalDatasource.
        :type name: str
        """
        self._name = name

    @property
    def types(self):
        r"""Gets the types of this ComponentExternalDatasource.

        外部数据源类型

        :return: The types of this ComponentExternalDatasource.
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        r"""Sets the types of this ComponentExternalDatasource.

        外部数据源类型

        :param types: The types of this ComponentExternalDatasource.
        :type types: list[str]
        """
        self._types = types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComponentExternalDatasource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
